Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(691)

Unified Diff: chrome/browser/ui/views/payments/payment_request_views_util.h

Issue 2859193004: Remove GridLayout::SetInsets in favor of an empty border on the host. (Closed)
Patch Set: missed a merge problem Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/payments/payment_request_views_util.h
diff --git a/chrome/browser/ui/views/payments/payment_request_views_util.h b/chrome/browser/ui/views/payments/payment_request_views_util.h
index 1e6c1b32c588bd784763bc7b4029921cd21657d1..752da09d079528c244bb2394ffe2165727f95296 100644
--- a/chrome/browser/ui/views/payments/payment_request_views_util.h
+++ b/chrome/browser/ui/views/payments/payment_request_views_util.h
@@ -11,6 +11,7 @@
#include "base/strings/string16.h"
#include "components/payments/mojom/payment_request.mojom.h"
#include "third_party/skia/include/core/SkColor.h"
+#include "ui/gfx/geometry/insets.h"
namespace autofill {
class AutofillProfile;
@@ -113,9 +114,12 @@ std::unique_ptr<views::View> GetContactInfoLabel(
const PaymentOptionsProvider& options,
const PaymentsProfileComparator& comp);
-// Creates a views::Border object that can paint the gray horizontal ruler used
-// as a separator between items in the Payment Request dialog.
-std::unique_ptr<views::Border> CreatePaymentRequestRowBorder(SkColor color);
+// Creates a views::Border object with |insets| that can paint the gray
+// horizontal ruler used as a separator between items in the Payment Request
+// dialog.
+std::unique_ptr<views::Border> CreatePaymentRequestRowBorder(
+ SkColor color,
+ const gfx::Insets& insets);
// Creates a label with a bold font.
std::unique_ptr<views::Label> CreateBoldLabel(const base::string16& text);

Powered by Google App Engine
This is Rietveld 408576698